@@ -115,7 +115,7 @@ impl TLine {
         strings.push(TString::new("", ": "));
         if let Some((module, function)) = key.rsplit_once("::") {
             strings.push(TString {
-                csi: "".to_string(),
+                csi: String::new(),
                 raw: format!("{module}::"),
             });
             strings.push(TString::new(CSI_BOLD_ORANGE, function));
@@ -124,13 +124,28 @@ impl TLine {
         }
         TLine { strings }
     }
+    pub fn passed(key: &str) -> Self {
+        let mut strings = Vec::with_capacity(4);
+        strings.push(TString::new(CSI_BOLD_GREEN, "passed"));
+        strings.push(TString::new("", ": "));
+        if let Some((module, function)) = key.rsplit_once("::") {
+            strings.push(TString {
+                csi: String::new(),
+                raw: format!("{module}::"),
+            });
+            strings.push(TString::new(CSI_BOLD_GREEN, function));
+        } else {
+            strings.push(TString::new(CSI_BOLD_GREEN, key));
+        }
+        TLine { strings }
+    }
     pub fn add_badge(
         &mut self,
         badge: TString,
     ) {
         self.strings.push(badge);
         self.strings.push(TString {
-            csi: "".to_string(),
+            csi: String::new(),
             raw: " ".to_string(),
         });
     }
@@ -153,7 +168,7 @@ impl TLine {
         }
         Ok(())
     }
-    /// draw the line but without taking more than cols_max cols.
+    /// draw the line but without taking more than `cols_max` cols.
     /// Return the number of cols written
     pub fn draw_in(
         &self,
